import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { KinesisVideoClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../KinesisVideoClient";
import { DescribeMappedResourceConfigurationInput, DescribeMappedResourceConfigurationOutput } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeMappedResourceConfigurationCommand}.
 */
export interface DescribeMappedResourceConfigurationCommandInput extends DescribeMappedResourceConfigurationInput {
}
/**
 * @public
 *
 * The output of {@link DescribeMappedResourceConfigurationCommand}.
 */
export interface DescribeMappedResourceConfigurationCommandOutput extends DescribeMappedResourceConfigurationOutput, __MetadataBearer {
}
declare const DescribeMappedResourceConfigurationCommand_base: {
    new (input: DescribeMappedResourceConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeMappedResourceConfigurationCommandInput, DescribeMappedResourceConfigurationCommandOutput, KinesisVideoClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * @public
 * <p>Returns the most current information about the stream. The <code>streamName</code>
 *             or <code>streamARN</code> should be provided in the input.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { KinesisVideoClient, DescribeMappedResourceConfigurationCommand } from "@aws-sdk/client-kinesis-video"; // ES Modules import
 * // const { KinesisVideoClient, DescribeMappedResourceConfigurationCommand } = require("@aws-sdk/client-kinesis-video"); // CommonJS import
 * const client = new KinesisVideoClient(config);
 * const input = { // DescribeMappedResourceConfigurationInput
 *   StreamName: "STRING_VALUE",
 *   StreamARN: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new DescribeMappedResourceConfigurationCommand(input);
 * const response = await client.send(command);
 * // { // DescribeMappedResourceConfigurationOutput
 * //   MappedResourceConfigurationList: [ // MappedResourceConfigurationList
 * //     { // MappedResourceConfigurationListItem
 * //       Type: "STRING_VALUE",
 * //       ARN: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param DescribeMappedResourceConfigurationCommandInput - {@link DescribeMappedResourceConfigurationCommandInput}
 * @returns {@link DescribeMappedResourceConfigurationCommandOutput}
 * @see {@link DescribeMappedResourceConfigurationCommandInput} for command's `input` shape.
 * @see {@link DescribeMappedResourceConfigurationCommandOutput} for command's `response` shape.
 * @see {@link KinesisVideoClientResolvedConfig | config} for KinesisVideoClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have required permissions to perform this operation.</p>
 *
 * @throws {@link ClientLimitExceededException} (client fault)
 *  <p>Kinesis Video Streams has throttled the request because you have exceeded the limit of
 *             allowed client calls. Try making the call later.</p>
 *
 * @throws {@link InvalidArgumentException} (client fault)
 *  <p>The value for this input parameter is invalid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Amazon Kinesis Video Streams can't find the stream that you specified.</p>
 *
 * @throws {@link KinesisVideoServiceException}
 * <p>Base exception class for all service exceptions from KinesisVideo service.</p>
 *
 */
export declare class DescribeMappedResourceConfigurationCommand extends DescribeMappedResourceConfigurationCommand_base {
}
